.. _installing:

==========
Installing
==========

To install ``xrtr``, use ``pip`` (or your favorite Python package manager), like::

    pip install xrtr

And you're ready to the next step. Hooray!

.. warning::

    At this time, ``xrtr`` binary packages are only available for Linux. Other platforms will be added in the future. PRs are welcome!
